"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createHighlighter = createHighlighter;
exports.loadLanguage = loadLanguage;
exports.loadTheme = loadTheme;
exports.processTokens = processTokens;
var _core = require("../../../dist/cache/core/core.js");
var _engineJavascript = require("../../../dist/cache/core/engine-javascript.js");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
let state = null;
function getState() {
  return state;
}
function setState(newState) {
  state = newState;
}
async function importLanguage(lang) {
  try {
    const module = await (specifier => new Promise(r => r(specifier)).then(s => _interopRequireWildcard(require(s))))(`../dist/cache/langs/${lang}.js`);
    return module.default;
  } catch (error) {
    console.error(`Failed to load language '${lang}':`, error);
    throw new Error(`Language '${lang}' not found in cache`);
  }
}
async function importTheme(theme) {
  try {
    const module = await (specifier => new Promise(r => r(specifier)).then(s => _interopRequireWildcard(require(s))))(`../dist/cache/themes/${theme}.js`);
    return module.default;
  } catch (error) {
    console.error(`Failed to load theme '${theme}':`, error);
    throw new Error(`Theme '${theme}' not found in cache`);
  }
}
async function initializeHighlighter(langs, themes) {
  const [langModules, themeModules] = await Promise.all([Promise.all(langs.map(importLanguage)), Promise.all(themes.map(importTheme))]);
  return (0, _core.createHighlighterCore)({
    engine: (0, _engineJavascript.createJavaScriptRegexEngine)(),
    langs: langModules,
    themes: themeModules
  });
}
async function loadAdditionalResources(currentState, langs, themes) {
  const newLangs = langs.filter(lang => !currentState.loadedLanguages.has(lang));
  const newThemes = themes.filter(theme => !currentState.loadedThemes.has(theme));
  if (newLangs.length === 0 && newThemes.length === 0) {
    return currentState;
  }
  await Promise.all([...newLangs.map(async lang => {
    const langModule = await importLanguage(lang);
    await currentState.highlighter.loadLanguage(langModule);
  }), ...newThemes.map(async theme => {
    const themeModule = await importTheme(theme);
    await currentState.highlighter.loadTheme(themeModule);
  })]);
  return {
    highlighter: currentState.highlighter,
    loadedLanguages: new Set([...currentState.loadedLanguages, ...newLangs]),
    loadedThemes: new Set([...currentState.loadedThemes, ...themes])
  };
}
async function createHighlighter({
  langs,
  themes
}) {
  if (!langs?.length || !themes?.length) {
    throw new Error('Please provide both `langs` and `themes` when creating a highlighter.');
  }
  try {
    const currentState = getState();
    if (currentState) {
      const newState = await loadAdditionalResources(currentState, langs, themes);
      setState(newState);
      return newState.highlighter;
    }
    const highlighter = await initializeHighlighter(langs, themes);
    const newState = {
      highlighter,
      loadedLanguages: new Set(langs),
      loadedThemes: new Set(themes)
    };
    setState(newState);
    return highlighter;
  } catch (error) {
    console.error('Failed to create highlighter:', error);
    throw error;
  }
}
async function loadTheme(theme) {
  const currentState = getState();
  if (!currentState) {
    throw new Error('Highlighter not initialized');
  }
  if (currentState.loadedThemes.has(theme)) {
    return;
  }
  const themeModule = await importTheme(theme);
  await currentState.highlighter.loadTheme(themeModule);
  setState({
    ...currentState,
    loadedThemes: new Set([...currentState.loadedThemes, theme])
  });
}
async function loadLanguage(lang) {
  const currentState = getState();
  if (!currentState) {
    throw new Error('Highlighter not initialized');
  }
  if (currentState.loadedLanguages.has(lang)) {
    return;
  }
  const langModule = await importLanguage(lang);
  await currentState.highlighter.loadLanguage(langModule);
  setState({
    ...currentState,
    loadedLanguages: new Set([...currentState.loadedLanguages, lang])
  });
}
function processTokens(tokens) {
  return tokens.map(token => ({
    content: token.content,
    color: token.color || '#000000',
    fontStyle: token.fontStyle?.toString()
  }));
}
//# sourceMappingURL=index.js.map